# Quine

- Quine is not evil
- The verifiable compiler compiler.
- Minimal build root and trust anchor for compiler toolchains.
- *Quine is a verifiable build root and trust anchor for reproducible compiler infrastructure.*
